@@ -21,10 +21,6 @@ __authors__ = 'Victor Olaya, Håvard Tveite'
 __date__ = 'August 2012'
 __copyright__ = '(C) 2012, Victor Olaya'
 
-# This will get replaced with a git SHA1 when you do a git archive
-
-__revision__ = '9b176802e5512bc310765d8ebe4e44b5f4663453'
-
 import os
 
 from qgis.PyQt.QtGui import QIcon
@@ -50,7 +46,6 @@ pluginPath = os.path.split(os.path.split(os.path.dirname(__file__))[0])[0]
 
 
 class VoronoiPolygons(QgisAlgorithm):
-
     INPUT = 'INPUT'
     BUFFER = 'BUFFER'
     OUTPUT = 'OUTPUT'
@@ -78,7 +73,7 @@ class VoronoiPolygons(QgisAlgorithm):
         self.addParameter(
             QgsProcessingParameterNumber(
                 self.BUFFER, self.tr('Buffer region (% of extent)'),
-                minValue=0.0, maxValue=9999999999, defaultValue=0.0))
+                minValue=0.0, defaultValue=0.0))
         self.addParameter(
             QgsProcessingParameterFeatureSink(
                 self.OUTPUT, self.tr('Voronoi polygons'),
@@ -90,6 +85,9 @@ class VoronoiPolygons(QgisAlgorithm):
     def displayName(self):
         return self.tr('Voronoi polygons')
 
+    def tags(self):
+        return self.tr('thiessen').split(',')
+
     def processAlgorithm(self, parameters, context, feedback):
         source = self.parameterAsSource(parameters, self.INPUT, context)
         if source is None:
@@ -285,12 +283,12 @@ class VoronoiPolygons(QgisAlgorithm):
                 # Only one (left) vertex
                 if c.lines[edge[0]][1] == 0:
                     # Vertical line
-                    #xtemp = c.lines[edge[0]][2] / c.lines[edge[0]][0]
+                    # xtemp = c.lines[edge[0]][2] / c.lines[edge[0]][0]
                     xtemp = c.vertices[edge[1]][0]
                     ytemp = 0 - 1
-                    #if c.vertices[edge[1]][1] > height / 2:
+                    # if c.vertices[edge[1]][1] > height / 2:
                     #    ytemp = height
-                    #else:
+                    # else:
                     #    ytemp = 0
                 else:
                     # Create an end of the line at the right edge - OK
@@ -309,12 +307,12 @@ class VoronoiPolygons(QgisAlgorithm):
                 # Only one (right) vertex
                 if c.lines[edge[0]][1] == 0:
                     # Vertical line
-                    #xtemp = c.lines[edge[0]][2] / c.lines[edge[0]][0]
+                    # xtemp = c.lines[edge[0]][2] / c.lines[edge[0]][0]
                     xtemp = c.vertices[edge[2]][0]
                     ytemp = height + 1
-                    #if c.vertices[edge[2]][1] > height / 2:
+                    # if c.vertices[edge[2]][1] > height / 2:
                     #    ytemp = height
-                    #else:
+                    # else:
                     #    ytemp = 0.0
                 else:
                     # End the line at the left edge - OK
@@ -381,7 +379,7 @@ class VoronoiPolygons(QgisAlgorithm):
         # points is not a problem - will be ignored later).
         # a) Extreme input points (lowest, leftmost, rightmost, highest)
         #    A point can be extreme on both axis
-        if pt_x == xmin:   # leftmost point
+        if pt_x == xmin:  # leftmost point
             if XMinNumber == 0:
                 bndpoints.append(QgsPointXY(extent.xMinimum(),
                                             extent.yMinimum()))
@@ -394,7 +392,7 @@ class VoronoiPolygons(QgisAlgorithm):
                 elif hasYMax:
                     bndpoints.append(QgsPointXY(extent.xMinimum(),
                                                 height + extent.yMinimum()))
-        elif pt_x == xmax:   # rightmost point
+        elif pt_x == xmax:  # rightmost point
             if XMaxNumber == 0:
                 bndpoints.append(QgsPointXY(width + extent.xMinimum(),
                                             extent.yMinimum()))
@@ -407,7 +405,7 @@ class VoronoiPolygons(QgisAlgorithm):
                 elif hasYMax:
                     bndpoints.append(QgsPointXY(width + extent.xMinimum(),
                                                 height + extent.yMinimum()))
-        if pt_y == ymin:    # lowest point
+        if pt_y == ymin:  # lowest point
             if YMinNumber == 0:
                 bndpoints.append(QgsPointXY(extent.xMinimum(),
                                             extent.yMinimum()))
